@@ -162,6 +162,8 @@ struct PuglInternalsImpl {
 	}
 
 	if (self) {
+		// we could implement UI scaling instead
+		[self setWantsBestResolutionOpenGLSurface: NO];
 		[[self openGLContext] makeCurrentContext];
 		[self reshape];
 	}
@@ -595,6 +597,8 @@ puglCreateWindow(PuglView* view, const char* title)
 	if (view->parent) {
 		NSView* pview = (NSView*)view->parent;
 		[pview addSubview:impl->glview];
+		// required to get mouse move events in Ableton Live (and possibly other hosts)
+		[[pview window] setAcceptsMouseMovedEvents: YES];
 		[impl->glview setHidden:NO];
 	} else {
 		NSString* titleString = [[NSString alloc]
@@ -630,6 +634,10 @@ puglCreateWindow(PuglView* view, const char* title)
                         // modal dialogs are usually centered on macOS
                         // (this window is not really modal, but at least centered)
                         [window center];
+                        // display new window above transient parent window
+                        NSView *tp_nsview = (NSView *) view->transient_parent;
+                        NSWindow *tp_window = [tp_nsview window];
+                        [tp_window addChildWindow: window ordered: NSWindowAbove];
                 }
 	}
 
