@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 
 import sys
 import math
@@ -23,4 +23,7 @@ for x in signal:
   energy += x * x
 
 energy /= len (signal)
-print 10 * math.log10 (energy)
+if energy > 0:
+  print (10 * math.log10 (energy))
+else:
+  print (-200)
