@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smmain.hh"
 #include "smrandom.hh"
@@ -63,7 +63,8 @@ encode_decode (vector<float>& audio_in, vector<float>& audio_out)
   encoder.save (sm_file);
 
   WavSet wav_set;
-  LiveDecoder decoder (&wav_set);
+  LiveDecoder decoder (&wav_set, enc_params.mix_freq);
+  RTMemoryArea rt_memory_area;
 
   WavSetWave new_wave;
   new_wave.midi_note = 60; // doesn't matter
@@ -80,8 +81,8 @@ encode_decode (vector<float>& audio_in, vector<float>& audio_out)
   decoder.enable_noise (false);
   for (double freq = 10; freq < 70000; freq = min (freq * 1.1, freq + 10))
     {
-      decoder.retrigger (0, freq, 127, enc_params.mix_freq);
-      decoder.process (audio_out.size(), nullptr, &audio_out[0]);
+      decoder.retrigger (0, freq, 127);
+      decoder.process (rt_memory_area, audio_out.size(), nullptr, &audio_out[0]);
       float peak = 0;
       for (size_t i = 0; i < audio_out.size(); i++)
         {
