@@ -1,8 +1,8 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smadsrenvelope.hh"
 #include "smmain.hh"
-#include "smmath.hh"
+#include "smutils.hh"
 
 #include <stdlib.h>
 
