@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smmain.hh"
 #include "smrandom.hh"
@@ -66,7 +66,8 @@ encode_decode (vector<float>& audio_in, vector<float>& audio_out)
   encoder.save (sm_file);
 
   WavSet wav_set;
-  LiveDecoder decoder (&wav_set);
+  RTMemoryArea rt_memory_area;
+  LiveDecoder decoder (&wav_set, enc_params.mix_freq);
 
   WavSetWave new_wave;
   new_wave.midi_note = 60; // doesn't matter
@@ -81,8 +82,8 @@ encode_decode (vector<float>& audio_in, vector<float>& audio_out)
   assert (!error);
 
   float freq = 440;
-  decoder.retrigger (0, freq, 127, enc_params.mix_freq);
-  decoder.process (audio_out.size(), nullptr, &audio_out[0]);
+  decoder.retrigger (0, freq, 127);
+  decoder.process (rt_memory_area, audio_out.size(), nullptr, &audio_out[0]);
 }
 
 void
