@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smnoisedecoder.hh"
 #include "smifftsynth.hh"
@@ -30,6 +30,10 @@ main (int argc, char **argv)
   for (int i = 0; i < 32; i++)
     audio_block.noise.push_back (sm_factor2idb (random.random_double_range (0.1, 1.0)));
 
+  RTMemoryArea rt_memory_area;
+  RTAudioBlock rt_audio_block (&rt_memory_area);
+  rt_audio_block.assign (audio_block);
+
   const int RUNS = 20000, REPS = 13;
 
   vector<float> samples (block_size);
@@ -46,7 +50,7 @@ main (int argc, char **argv)
           for (int r = 0; r < RUNS; r++)
             {
               ifft_synth.clear_partials();
-              noise_dec.process (audio_block, ifft_synth.fft_buffer(), spect ? NoiseDecoder::FFT_SPECTRUM : NoiseDecoder::DEBUG_NO_OUTPUT);
+              noise_dec.process (rt_audio_block, ifft_synth.fft_buffer(), spect ? NoiseDecoder::FFT_SPECTRUM : NoiseDecoder::DEBUG_NO_OUTPUT);
               if (ifft)
                 ifft_synth.get_samples (&samples[0]);
             }
