@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smmain.hh"
 #include "smrandom.hh"
@@ -184,11 +184,12 @@ decode (vector<float>& audio_out, int sr)
   Error error = wav_set.load ("testnoisesr.tmp.smset");
   assert (!error);
 
-  LiveDecoder decoder (&wav_set);
+  RTMemoryArea rt_memory_area;
+  LiveDecoder decoder (&wav_set, sr);
 
   float freq = 440;
-  decoder.retrigger (0, freq, 127, sr);
-  decoder.process (audio_out.size(), nullptr, &audio_out[0]);
+  decoder.retrigger (0, freq, 127);
+  decoder.process (rt_memory_area, audio_out.size(), nullptr, &audio_out[0]);
 }
 
 void
