@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smmorphplan.hh"
 #include "smmorphplanvoice.hh"
@@ -11,25 +11,23 @@
 using namespace SpectMorph;
 
 static void
-preinit_plan (MorphPlanPtr plan)
+preinit_plan (MorphPlan& plan)
 {
-  MorphPlanSynth synth (44100);
-  synth.add_voice();
-  synth.update_plan (plan);
+  MorphPlanSynth synth (44100, 1);
+
+  auto update = synth.prepare_update (plan);
+  synth.apply_update (update);
 }
 
 static void
-measure_update (MorphPlanPtr plan, size_t n_voices)
+measure_update (MorphPlan& plan, size_t n_voices)
 {
-  MorphPlanSynth synth (44100);
-  for (size_t i = 0; i < n_voices; i++)
-    synth.add_voice();
+  MorphPlanSynth synth (44100, n_voices);
 
   size_t runs = 1000000 / n_voices;
-
   double start = get_time();
   for (size_t j = 0; j < runs; j++)
-    synth.update_plan (plan);
+    synth.apply_update (synth.prepare_update (plan));
   double end = get_time();
 
   printf ("update (%zd voices): %f updates per ms\n", n_voices, 1 / ((end - start) * 1000 / runs));
@@ -46,18 +44,15 @@ main (int argc, char **argv)
     }
 
   Project      project;
-  MorphPlanPtr plan = new MorphPlan (project);
-  GenericIn *in = StdioIn::open (argv[1]);
-  if (!in)
-    {
-      g_printerr ("Error opening '%s'.\n", argv[1]);
-      exit (1);
-    }
-  plan->load (in);
-  delete in;
+  project.set_mix_freq (48000);
+
+  Error error = project.load (argv[1]);
+  assert (!error);
+
+  MorphPlan *plan = project.morph_plan();
 
   fprintf (stderr, "SUCCESS: plan loaded, %zd operators found.\n", plan->operators().size());
-  preinit_plan (plan);
-  measure_update (plan, 1);
-  measure_update (plan, 10);
+  preinit_plan (*plan);
+  measure_update (*plan, 1);
+  measure_update (*plan, 64);
 }
