@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include <stdio.h>
 #include <assert.h>
@@ -8,6 +8,7 @@
 #include "smmath.hh"
 
 #include <algorithm>
+#include <random>
 
 using namespace SpectMorph;
 using std::vector;
@@ -16,7 +17,6 @@ struct PData
 {
   uint16_t freq;
   uint16_t mag;
-  uint16_t phase;
 };
 
 float
@@ -26,7 +26,7 @@ something()
 }
 
 void
-randomize_and_check (AudioBlock& block)
+randomize_and_check (AudioBlock& block, std::mt19937& rand_gen)
 {
   vector<PData> partials;
 
@@ -35,12 +35,11 @@ randomize_and_check (AudioBlock& block)
       PData pd;
       pd.freq = sm_freq2ifreq (i + something());
       pd.mag = sm_factor2idb (i * 0.1 + something());
-      pd.phase = g_random_int_range (0, 65536);
 
       partials.push_back (pd);
     }
   vector<PData> partials_shuffle = partials;
-  std::random_shuffle (partials_shuffle.begin(), partials_shuffle.end());
+  std::shuffle (partials_shuffle.begin(), partials_shuffle.end(), rand_gen);
 
   assert (partials.size() == partials_shuffle.size());
 
@@ -52,7 +51,6 @@ randomize_and_check (AudioBlock& block)
     {
       block.freqs.push_back (partials_shuffle[i].freq);
       block.mags.push_back (partials_shuffle[i].mag);
-      block.phases.push_back (partials_shuffle[i].phase);
     }
 
   AudioBlock check_block = block;
@@ -61,7 +59,6 @@ randomize_and_check (AudioBlock& block)
     {
       assert (check_block.freqs[i] == partials[i].freq);
       assert (check_block.mags[i] == partials[i].mag);
-      assert (check_block.phases[i] == partials[i].phase);
     }
 }
 
@@ -72,8 +69,11 @@ main (int argc, char **argv)
 
   AudioBlock block_a, block_b, block_c;
 
-  randomize_and_check (block_a);
-  randomize_and_check (block_b);
+  std::random_device rd;
+  std::mt19937 rand_gen (rd());
+
+  randomize_and_check (block_a, rand_gen);
+  randomize_and_check (block_b, rand_gen);
 
   const unsigned int runs = 1000000;
 
