@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smwavset.hh"
 #include "smmain.hh"
@@ -257,7 +257,8 @@ main (int argc, char **argv)
       exit (1);
     }
 
-  LiveDecoder decoder (&smset);
+  RTMemoryArea rt_memory_area;
+  LiveDecoder decoder (&smset, options.rate);
 
   decoder.enable_original_samples (options.enable_original_samples);
   decoder.enable_sines (options.sines_enabled);
@@ -287,8 +288,8 @@ main (int argc, char **argv)
     }
 
   vector<float> audio_out (len);
-  decoder.retrigger (0, options.freq, 127, options.rate);
-  decoder.process (audio_out.size(), freq_in.size() ? &freq_in[0] : nullptr, &audio_out[0]);
+  decoder.retrigger (0, options.freq, 127);
+  decoder.process (rt_memory_area, audio_out.size(), freq_in.size() ? &freq_in[0] : nullptr, &audio_out[0]);
 
   // hacky way to remove tail silence
   while (!audio_out.empty() && audio_out.back() == 0)
