@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smmorphplanvoice.hh"
 #include "smmorphplansynth.hh"
@@ -180,7 +180,7 @@ class Player
   MorphPlanVoice *voice;
 
   Project         project;
-  MorphPlanPtr    plan;
+  MorphPlan      *plan;
   MorphPlanSynth  synth;
 public:
   Player();
@@ -194,27 +194,28 @@ Player::Player() :
   linear_op (0),
   grid_op (0),
   voice (0),
-  plan (new MorphPlan (project)),
-  synth (options.rate)
+  plan (project.morph_plan()),
+  synth (options.rate, 1)
 {
 }
 
 void
 Player::load_plan (const string& filename)
 {
-  GenericIn *in = StdioIn::open (filename);
-  if (!in)
+  project.set_mix_freq (options.rate);
+
+  Error error = project.load (filename);
+  if (error)
     {
-      g_printerr ("Error opening '%s'.\n", filename.c_str());
+      fprintf (stderr, "%s: loading file '%s' failed: %s\n", options.program_name.c_str(), filename.c_str(), error.message());
       exit (1);
     }
-  plan->load (in);
-  delete in;
 
   fprintf (stderr, "SUCCESS: plan loaded, %zd operators found.\n", plan->operators().size());
 
-  voice = synth.add_voice();
-  synth.update_plan (plan);
+  voice = synth.voice (0);
+  auto update = synth.prepare_update (*plan);
+  synth.apply_update (update);
   assert (voice->output());
 
   /* search operators for --fade, --fade-env */
@@ -243,6 +244,10 @@ Player::retrigger()
 void
 Player::compute_samples (vector<float>& samples)
 {
+  double ppq_pos = 0;
+  TimeInfoGenerator time_info_gen (voice->mix_freq());
+  RTMemoryArea rt_memory_area;
+
   uint64 audio_time_stamp = 0;
   const size_t STEP = 100;
   for (size_t i = 0; i < samples.size(); i += STEP)
@@ -275,19 +280,23 @@ Player::compute_samples (vector<float>& samples)
             {
               g_assert_not_reached();
             }
-          synth.update_plan (plan);
+          auto update = synth.prepare_update (*plan);
+          synth.apply_update (update);
         }
 
       size_t todo = min (STEP, samples.size() - i);
 
-      TimeInfo time_info;
-      time_info.time_ms = audio_time_stamp * 1000.0 / voice->mix_freq();
+      double tempo = 120;
+      time_info_gen.start_block (audio_time_stamp, todo, ppq_pos, tempo);
+
+      synth.update_shared_state (time_info_gen.time_info (0));
 
       float *audio_out[1] = { &samples[i] };
-      voice->output()->process (time_info, todo, audio_out, 1);
+      voice->output()->process (time_info_gen, rt_memory_area, todo, audio_out, 1);
+      rt_memory_area.free_all();
 
-      synth.update_shared_state (time_info);
       audio_time_stamp += todo;
+      ppq_pos += todo / voice->mix_freq() * (tempo / 60);
     }
 }
 
