@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smwavset.hh"
 #include "smlivedecoder.hh"
@@ -48,7 +48,8 @@ main (int argc, char **argv)
   int priority = adjust_priority();
   const double ns_per_sec = 1e9;
 
-  LiveDecoder decoder (&smset);
+  RTMemoryArea rt_memory_area;
+  LiveDecoder decoder (&smset, 48000);
   if (argc == 4 && (string (argv[3]) == "avg" || string (argv[3]) == "avg-all"))
     {
       float ns_per_sample[5] = { 0, };
@@ -67,8 +68,8 @@ main (int argc, char **argv)
               vector<float> audio_out (n);
 
               // avoid measuring setup time
-              decoder.retrigger (0, freq, 127, 48000);
-              decoder.process (n, nullptr, &audio_out[0]);
+              decoder.retrigger (0, freq, 127);
+              decoder.process (rt_memory_area, n, nullptr, &audio_out[0]);
 
               double best_time = 1e7;
               for (int rep = 0; rep < 25; rep++)
@@ -76,8 +77,8 @@ main (int argc, char **argv)
                   double start_t = get_time();
                   for (int l = 0; l < runs; l++)
                     {
-                      decoder.retrigger (0, freq, 127, 48000);
-                      decoder.process (n, nullptr, &audio_out[0]);
+                      decoder.retrigger (0, freq, 127);
+                      decoder.process (rt_memory_area, n, nullptr, &audio_out[0]);
                     }
                   double end_t = get_time();
                   best_time = min (best_time, (end_t - start_t));
@@ -102,8 +103,8 @@ main (int argc, char **argv)
       float audio_out[n];
 
       // avoid measuring setup time
-      decoder.retrigger (0, freq, 127, 48000);
-      decoder.process (n, nullptr, audio_out);
+      decoder.retrigger (0, freq, 127);
+      decoder.process (rt_memory_area, n, nullptr, audio_out);
 
       double best_time = 1e7;
       for (int rep = 0; rep < 25; rep++)
@@ -111,8 +112,8 @@ main (int argc, char **argv)
           double start_t = get_time();
           for (int l = 0; l < runs; l++)
             {
-              decoder.retrigger (0, freq, 127, 48000);
-              decoder.process (n, nullptr, audio_out);
+              decoder.retrigger (0, freq, 127);
+              decoder.process (rt_memory_area, n, nullptr, audio_out);
             }
           double end_t = get_time();
           best_time = min (best_time, (end_t - start_t));
@@ -127,8 +128,8 @@ main (int argc, char **argv)
       const int bits = 16;
 
       vector<float> audio_out (SR * 20);
-      decoder.retrigger (0, freq, 127, SR);
-      decoder.process (audio_out.size(), nullptr, &audio_out[0]);
+      decoder.retrigger (0, freq, 127);
+      decoder.process (rt_memory_area, audio_out.size(), nullptr, &audio_out[0]);
 
       std::string export_wav = "tld.wav";
 
@@ -148,8 +149,8 @@ main (int argc, char **argv)
           const int runs = 40;
           for (int l = 0; l < runs; l++)
             {
-              decoder.retrigger (0, freq, 127, 48000);
-              decoder.process (n, nullptr, &audio_out[0]);
+              decoder.retrigger (0, freq, 127);
+              decoder.process (rt_memory_area, n, nullptr, &audio_out[0]);
             }
           double end_t = get_time();
           sm_printf ("%d %.17g\n", n, (end_t - start_t) * ns_per_sec / n / runs);
