@@ -1,4 +1,4 @@
-// Licensed GNU LGPL v3 or later: http://www.gnu.org/licenses/lgpl.html
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl-2.1.html
 
 #include "smvstui.hh"
 #include "smvstplugin.hh"
@@ -13,7 +13,7 @@ using namespace SpectMorph;
 using std::string;
 using std::vector;
 
-VstUI::VstUI (MorphPlanPtr plan, VstPlugin *plugin) :
+VstUI::VstUI (MorphPlan *plan, VstPlugin *plugin) :
   morph_plan (plan),
   plugin (plugin)
 {
